attachtags package
==================

Submodules
----------

attachtags.argtomap module
--------------------------

.. automodule:: attachtags.argtomap
   :members:
   :undoc-members:
   :show-inheritance:

attachtags.attachtags module
----------------------------

.. automodule:: attachtags.attachtags
   :members:
   :undoc-members:
   :show-inheritance:

attachtags.cli module
---------------------

.. automodule:: attachtags.cli
   :members:
   :undoc-members:
   :show-inheritance:

attachtags.parserbuilder module
-------------------------------

.. automodule:: attachtags.parserbuilder
   :members:
   :undoc-members:
   :show-inheritance:

attachtags.tagmaps module
-------------------------

.. automodule:: attachtags.tagmaps
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: attachtags
   :members:
   :undoc-members:
   :show-inheritance:
